@@ -273,6 +273,7 @@
 #define __NR_pkey_mprotect 288
 #define __NR_pkey_alloc 289
 #define __NR_pkey_free 290
+#define __NR_statx 291
 
 #define SYS_io_setup 0
 #define SYS_io_destroy 1
@@ -549,3 +550,4 @@
 #define SYS_pkey_mprotect 288
 #define SYS_pkey_alloc 289
 #define SYS_pkey_free 290
+#define SYS_statx 291
